@@ -11,6 +11,27 @@ from typing import Union
 from requests import Session
 
 
+class BlockSizeSetter(object):
+    def __set__(self, block_size, val):
+        if isinstance(val, int) and val > 0:
+            size = val
+        elif isinstance(val, str):
+            units = {'b': 1, 'k': 1024, 'm': 1048576, 'g': 21474836480}
+            num = int(val[:-1])
+            unit = units.get(val[-1].lower(), None)
+            if unit and num > 0:
+                size = num * unit
+            else:
+                raise ValueError('单位只支持B、K、M、G，数字必须为大于0的整数。')
+        else:
+            raise TypeError('split_size只能传入int或str，数字必须为大于0的整数。')
+
+        block_size._block_size = size
+
+    def __get__(self, block_size, objtype=None) -> int:
+        return block_size._block_size
+
+
 class PathSetter(object):
     def __set__(self, goal_path, val):
         if val is not None and not isinstance(val, (str, Path)):
